@@ -97,7 +97,7 @@ def video_get_exif(fn):
     # print data
 
     rotate = '0'
-    creation = ''
+    creation = datetime.strftime(datetime.now(), "%Y-%m-%d %H:%M:%S")
     process = Popen([conf.FFPROBE, '-show_streams', str(fn)],
                     stdout=PIPE,
                     stderr=PIPE)
