@@ -28,7 +28,7 @@ from django.conf import settings as conf
 from django.views.generic import DetailView, ListView, CreateView
 from django.views.generic.edit import ProcessFormView
 
-from management.commands.mediasync import get_exif, img_rotate
+from management.commands.utils import *
 from forms import PhotoForm
 
 
@@ -43,7 +43,7 @@ class Photos(TagMixin, ListView):
 
     template_name = "rgallery/photos.html"
     context_object_name = "photos"
-    paginate_by = 51
+    paginate_by = 150
 
     def get_queryset(self):
         return mymodels.Photo.objects.all().filter(status=1, folder__isnull=True).order_by('-capture_date')
@@ -129,7 +129,7 @@ class PhotoAdd(LoginRequiredMixin, SuperuserRequiredMixin, CreateView):
             nombre_imagen = str(os.path.basename(form.files['file'].name)).replace('/', '').replace(' ','_').replace(':','-')
 
             # Extracting Exif data
-            data_image = get_exif(form.files['file'])
+            data_image = img_get_exif(form.files['file'])
             capture_data = datetime.strptime(str(data_image['DateTimeOriginal']), "%Y:%m:%d %H:%M:%S")
 
             # Name (if exists in disk)
@@ -175,6 +175,19 @@ class PhotoDelete(LoginRequiredMixin, SuperuserRequiredMixin, ListView):
             return True
 
 
+class PhotoGetVideo(LoginRequiredMixin, ListView):
+
+    model = mymodels.Photo
+
+    def post(self, request, *args, **kwargs):
+        if self.request.is_ajax() and self.request.method == 'POST':
+            pk = json.loads(self.request.POST.get('pk', None))
+            photo = get_object_or_404(mymodels.Photo, pk=pk)
+            rendered = render_to_string('rgallery/_video.html',
+                                        {'video': photo.video})
+        return HttpResponse(rendered);
+
+
 class Videos(ListView):
 
     template_name = "rgallery/videos.html"
